@@ -1,6 +1,6 @@
 package App::Info::Util;
 
-# $Id: Util.pm 859 2004-11-19 23:59:15Z theory $
+# $Id: Util.pm 862 2004-11-20 19:11:40Z theory $
 
 =head1 NAME
 
@@ -46,9 +46,10 @@ class offers methods that simplify those tasks.
 
 use strict;
 use File::Spec ();
+use Config;
 use vars qw(@ISA $VERSION);
 @ISA = qw(File::Spec);
-$VERSION = '0.29';
+$VERSION = '0.30';
 
 my %path_dems = (MacOS   => qr',',
                  MSWin32 => qr';',
@@ -428,6 +429,26 @@ sub multi_search_file {
     return wantarray ? @ret{@regexen} : \@ret{@regexen};
 }
 
+=head2 lib_dirs
+
+  my @dirs = $util->lib_dirs;
+
+Returns a list of possible library directories to be searched. These are
+gathered from the C<libsdirs> and C<loclibpth> Config settings. These are
+useful for passing to C<first_cat_dir()> to search typical directories for
+library files.
+
+=cut
+
+sub lib_dirs {
+    grep { defined and length }
+    map { split ' ' }
+    grep { defined }
+    $Config{libsdirs},
+    $Config{loclibpth},
+    '/sw/lib';
+}
+
 1;
 __END__
 
